@@ -1,5 +1,5 @@
 /*
- *   Character mapping generated 09/07/10 17:54:20
+ *   Character mapping generated 11/18/10 11:54:12
  *
  *  This file contains the character classifications
  *  used by AutoGen and AutoOpts for identifying tokens.
@@ -116,6 +116,7 @@
 // false-type      "nNfF0\x00"
 // file-name       "/"           +suffix
 // end-token       "\x00"        +whitespace
+// end-list-entry  ","           +end-token
 //
 #endif /* 0 -- mapping spec. source */
 
@@ -126,30 +127,31 @@ static inline int is_opt_char_cat_char(char ch, opt_char_cat_mask_t mask) {
     unsigned int ix = (unsigned char)ch;
     return ((ix < 0x7F) && ((opt_char_cat[ix] & mask) != 0)); }
 
-#define IS_LOWER_CASE_CHAR(_c)     is_opt_char_cat_char((_c), 0x000001)
-#define IS_UPPER_CASE_CHAR(_c)     is_opt_char_cat_char((_c), 0x000002)
-#define IS_ALPHABETIC_CHAR(_c)     is_opt_char_cat_char((_c), 0x000003)
-#define IS_OCT_DIGIT_CHAR(_c)      is_opt_char_cat_char((_c), 0x000004)
-#define IS_DEC_DIGIT_CHAR(_c)      is_opt_char_cat_char((_c), 0x00000C)
-#define IS_HEX_DIGIT_CHAR(_c)      is_opt_char_cat_char((_c), 0x00001C)
-#define IS_ALPHANUMERIC_CHAR(_c)   is_opt_char_cat_char((_c), 0x00000F)
-#define IS_VAR_FIRST_CHAR(_c)      is_opt_char_cat_char((_c), 0x000023)
-#define IS_VARIABLE_NAME_CHAR(_c)  is_opt_char_cat_char((_c), 0x00002F)
-#define IS_OPTION_NAME_CHAR(_c)    is_opt_char_cat_char((_c), 0x00006F)
-#define IS_VALUE_NAME_CHAR(_c)     is_opt_char_cat_char((_c), 0x0000EF)
-#define IS_HORIZ_WHITE_CHAR(_c)    is_opt_char_cat_char((_c), 0x000100)
-#define IS_COMPOUND_NAME_CHAR(_c)  is_opt_char_cat_char((_c), 0x0003EF)
-#define IS_WHITESPACE_CHAR(_c)     is_opt_char_cat_char((_c), 0x000500)
-#define IS_UNQUOTABLE_CHAR(_c)     is_opt_char_cat_char((_c), 0x000800)
-#define IS_END_XML_TOKEN_CHAR(_c)  is_opt_char_cat_char((_c), 0x001500)
-#define IS_GRAPHIC_CHAR(_c)        is_opt_char_cat_char((_c), 0x002000)
-#define IS_PLUS_N_SPACE_CHAR(_c)   is_opt_char_cat_char((_c), 0x004500)
-#define IS_PUNCTUATION_CHAR(_c)    is_opt_char_cat_char((_c), 0x008000)
-#define IS_SUFFIX_CHAR(_c)         is_opt_char_cat_char((_c), 0x01000F)
-#define IS_SUFFIX_FMT_CHAR(_c)     is_opt_char_cat_char((_c), 0x03000F)
-#define IS_FALSE_TYPE_CHAR(_c)     is_opt_char_cat_char((_c), 0x040000)
-#define IS_FILE_NAME_CHAR(_c)      is_opt_char_cat_char((_c), 0x09000F)
-#define IS_END_TOKEN_CHAR(_c)      is_opt_char_cat_char((_c), 0x100500)
+#define IS_LOWER_CASE_CHAR(_c)      is_opt_char_cat_char((_c), 0x000001)
+#define IS_UPPER_CASE_CHAR(_c)      is_opt_char_cat_char((_c), 0x000002)
+#define IS_ALPHABETIC_CHAR(_c)      is_opt_char_cat_char((_c), 0x000003)
+#define IS_OCT_DIGIT_CHAR(_c)       is_opt_char_cat_char((_c), 0x000004)
+#define IS_DEC_DIGIT_CHAR(_c)       is_opt_char_cat_char((_c), 0x00000C)
+#define IS_HEX_DIGIT_CHAR(_c)       is_opt_char_cat_char((_c), 0x00001C)
+#define IS_ALPHANUMERIC_CHAR(_c)    is_opt_char_cat_char((_c), 0x00000F)
+#define IS_VAR_FIRST_CHAR(_c)       is_opt_char_cat_char((_c), 0x000023)
+#define IS_VARIABLE_NAME_CHAR(_c)   is_opt_char_cat_char((_c), 0x00002F)
+#define IS_OPTION_NAME_CHAR(_c)     is_opt_char_cat_char((_c), 0x00006F)
+#define IS_VALUE_NAME_CHAR(_c)      is_opt_char_cat_char((_c), 0x0000EF)
+#define IS_HORIZ_WHITE_CHAR(_c)     is_opt_char_cat_char((_c), 0x000100)
+#define IS_COMPOUND_NAME_CHAR(_c)   is_opt_char_cat_char((_c), 0x0003EF)
+#define IS_WHITESPACE_CHAR(_c)      is_opt_char_cat_char((_c), 0x000500)
+#define IS_UNQUOTABLE_CHAR(_c)      is_opt_char_cat_char((_c), 0x000800)
+#define IS_END_XML_TOKEN_CHAR(_c)   is_opt_char_cat_char((_c), 0x001500)
+#define IS_GRAPHIC_CHAR(_c)         is_opt_char_cat_char((_c), 0x002000)
+#define IS_PLUS_N_SPACE_CHAR(_c)    is_opt_char_cat_char((_c), 0x004500)
+#define IS_PUNCTUATION_CHAR(_c)     is_opt_char_cat_char((_c), 0x008000)
+#define IS_SUFFIX_CHAR(_c)          is_opt_char_cat_char((_c), 0x01000F)
+#define IS_SUFFIX_FMT_CHAR(_c)      is_opt_char_cat_char((_c), 0x03000F)
+#define IS_FALSE_TYPE_CHAR(_c)      is_opt_char_cat_char((_c), 0x040000)
+#define IS_FILE_NAME_CHAR(_c)       is_opt_char_cat_char((_c), 0x09000F)
+#define IS_END_TOKEN_CHAR(_c)       is_opt_char_cat_char((_c), 0x100500)
+#define IS_END_LIST_ENTRY_CHAR(_c)  is_opt_char_cat_char((_c), 0x300500)
 
 #ifdef AUTOOPTS_INTERNAL
 opt_char_cat_mask_t const opt_char_cat[128] = {
@@ -164,7 +166,7 @@ opt_char_cat_mask_t const opt_char_cat[128] = {
   /*   */ 0x000100, /* ! */ 0x00A800, /* " */ 0x00A000, /* # */ 0x00A000,
   /* $ */ 0x00A800, /* % */ 0x02A800, /* & */ 0x00A800, /* ' */ 0x00A000,
   /* ( */ 0x00A000, /* ) */ 0x00A000, /* * */ 0x00A000, /* + */ 0x00E800,
-  /* , */ 0x00A000, /* - */ 0x01A840, /* . */ 0x01AA00, /* / */ 0x0AB800,
+  /* , */ 0x20A000, /* - */ 0x01A840, /* . */ 0x01AA00, /* / */ 0x0AB800,
   /* 0 */ 0x042804, /* 1 */ 0x002804, /* 2 */ 0x002804, /* 3 */ 0x002804,
   /* 4 */ 0x002804, /* 5 */ 0x002804, /* 6 */ 0x002804, /* 7 */ 0x002804,
   /* 8 */ 0x002808, /* 9 */ 0x002808, /* : */ 0x00A880, /* ; */ 0x00A000,
